Crate borderless_id_types

Crate borderless_id_types 

Borderless ID-Types

This library contains various types that are used as IDs for different things in the borderless ecosystem.

Structs

AgentId
An agent-id used to identify software-agents in the borderless-ecosystem.
BlockIdentifier
Type used to identify blocks.
BorderlessId
The borderless-id used to identify participants in the borderless-network.
ContractId
A contract-id used to itentify different SmartContracts in the borderless-ecosystem.
Did
A decentralized-id used to itentify different assets and documents in the borderless-ecosystem.
ExternalId
An external-id used to identify external entities, that are not in the borderless-network.
FlowId
A flow-id used to identify Flows in a contract.
InvalidBlockIdentifier
InvalidTxIdentifier
TxIdentifier
Type used to identify transactions.
Uuid
A Universally Unique Identifier (UUID).

Functions

aid_prefix
Check weather or not an array of bytes contains the prefix of an AgentId.
bid_prefix
Check weather or not an array of bytes contains the prefix of a BorderlessId.
cid_prefix
Check weather or not an array of bytes contains the prefix of a ContractId.
did_prefix
Check weather or not an array of bytes contains the prefix of a Did.
eid_prefix
Check weather or not an array of bytes contains the prefix of an ExternalId.
fid_prefix
Check weather or not an array of bytes contains the prefix of a FlowId.