Borderless ID-Types
This library contains various types that are used as IDs for different things in the borderless ecosystem.
Structs
- AgentId
- An agent-id used to identify software-agents in the borderless-ecosystem.
- Block
Identifier - Type used to identify blocks.
- Borderless
Id - The borderless-id used to identify participants in the borderless-network.
- Contract
Id - A contract-id used to itentify different SmartContracts in the borderless-ecosystem.
- Did
- A decentralized-id used to itentify different assets and documents in the borderless-ecosystem.
- External
Id - An external-id used to identify external entities, that are not in the borderless-network.
- FlowId
- A flow-id used to identify
Flowsin a contract. - Invalid
Block Identifier - Invalid
TxIdentifier - TxIdentifier
- Type used to identify transactions.
- Uuid
- A Universally Unique Identifier (UUID).
Functions
- aid_
prefix - Check weather or not an array of bytes contains the prefix of an
AgentId. - bid_
prefix - Check weather or not an array of bytes contains the prefix of a
BorderlessId. - cid_
prefix - Check weather or not an array of bytes contains the prefix of a
ContractId. - did_
prefix - Check weather or not an array of bytes contains the prefix of a
Did. - eid_
prefix - Check weather or not an array of bytes contains the prefix of an
ExternalId. - fid_
prefix - Check weather or not an array of bytes contains the prefix of a
FlowId.